<!--suppress HtmlFormInputWithoutLabel -->
<input id="{{ input_id }}-input"
       class="form-input input-primary"
        {% if "default" in schema.__fields_set__ %}
       value="{{ schema.default }}"
        {% endif %}>

<script>
    document.getElementById("{{ input_id }}-input").addEventListener(
        "input", (e) => e.target.value = e.target.value.replace(/[^0-9.-]/g, "")
    );

    function get{{ input_id }}() {
        return getInputFunction('{{ input_id }}', _get{{ input_id }});
    }

    function _get{{ input_id }}() {
        return parseFloat(document.getElementById("{{ input_id }}-input").value);
    }

    formFunctions["{{ input_id }}"] = get{{ input_id }};
</script>
