<div class="flex text-neutral-200 bg-neutral-800 dark:bg-neutral-700 mb-1 rounded-t-lg pr-4 pl-8 pt-2 pb-2">
    <p id="{{ modal_id }}-modal-title" class="text-2xl">{{ title }}</p>
    <button class="material-symbols-outlined ml-auto mb-auto rounded-full p-1 bg-red-600 hover:bg-red-700 close-button"
            tabindex="-1"
            onclick="closeModal('{{ modal_id }}')">
        close
    </button>
</div>
