<!DOCTYPE html>
<!--suppress HtmlUnknownTarget -->
<html lang="en">
<head>
    <title>{{ error_title }}</title>

    <meta name="viewport" content="width=device-width, initial-scale=1" charset="UTF-8">

    {# Favicon #}
    <link rel="apple-touch-icon" sizes="57x57" href="/static/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/static/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/static/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/static/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/static/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/static/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/static/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/static/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/static/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"
          href="/static/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/static/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/static/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/static/favicon-16x16.png">
    <link rel="manifest" href="/static/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">

    {# Tailwind CSS #}
    <link href="/static/output.css" rel="stylesheet">

    {# Google Material Icons #}
    <link rel="stylesheet"
          href="https://fonts.googleapis.com/icon?family=Material+Icons">

    <script src="/static/tabella.js"></script>
    {# Set theme in head to avoid flash-bang. #}
    <script>
        if (isDark()) {
            document.documentElement.classList.add("dark")
        } else {
            document.documentElement.classList.remove("dark")
        }
    </script>
</head>

<body class="text-neutral-950 bg-neutral-500 dark:bg-neutral-950 dark:text-neutral-300">

<div class="mt-11 w-1/3 rounded-2xl mx-auto p-6 bg-neutral-100 dark:bg-neutral-800">
    <div class="ml-8 mr-8">
        <h1 class="text-4xl text-red-600 dark:text-red-500">{{ error_title }}</h1>
        <div class="text-lg m-4">
            {{ error_message }}
        </div>
        <div class="flex rounded-b-lg pb-4 pt-2">
            <a class="ml-8 mr-8 p-1 rounded-lg w-full submit-button text-center"
               href="/">
                Return to Docs
            </a>
        </div>
    </div>
</div>

</body>
</html>
